import React, { useState } from 'react';
import { BrowserRouter as Router, Route, Routes, Navigate } from 'react-router-dom';
import LoginPage from './pages/LoginPage'; // Login sayfası
import Navbar from './components/Navbar';  // Navbar bileşeni
import Sidebar from './components/Sidebar'; // Sidebar bileşeni
import AdminRoutes from './roles/AdminRoutes';  // Admin route bileşenleri
import DistributorRoutes from './roles/DistributorRoutes';  // Distributor route bileşenleri
import RetailerRoutes from './roles/RetailerRoutes';  // Retailer route bileşenleri
import CustomerRoutes from './roles/CustomerRoutes';  // Customer route bileşenleri

function App() {
  const [user, setUser] = useState(null);  // Kullanıcı verisini tutan durum

  const handleLogin = (userData) => {
    setUser(userData);  // Giriş yapan kullanıcının verilerini ayarlıyoruz
  };

  const handleLogout = () => {
    setUser(null);  // Kullanıcı çıkışı yaparsa, veriyi sıfırlıyoruz
  };

  return (
    <Router>
      {/* Eğer kullanıcı giriş yapmamışsa, giriş sayfası gösterilsin */}
      {!user ? (
        <LoginPage onLogin={handleLogin} />
      ) : (
        <div className="flex h-screen bg-gray-100">
          {/* Sidebar, kullanıcı rolüne göre gösterilecek */}
          <Sidebar user={user} onLogout={handleLogout} />
          <div className="flex-1 flex flex-col overflow-hidden">
            {/* Navbar, kullanıcı bilgisi ve çıkış fonksiyonu ile birlikte */}
            <Navbar user={user} onLogout={handleLogout} />
            <main className="flex-1 overflow-x-hidden overflow-y-auto bg-gray-200 p-4">
              {/* Kullanıcının rolüne göre yönlendirmeler */}
              <Routes>
                {user.role === 'admin' && <Route path="/*" element={<AdminRoutes />} />}
                {user.role === 'distributor' && <Route path="/*" element={<DistributorRoutes />} />}
                {user.role === 'retailer' && <Route path="/*" element={<RetailerRoutes />} />}
                {user.role === 'customer' && <Route path="/*" element={<CustomerRoutes />} />}
                
                {/* Tanımlanmayan yollar için yönlendirme */}
                <Route path="*" element={<Navigate to="/" />} />
              </Routes>
            </main>
          </div>
        </div>
      )}
    </Router>
  );
}

export default App;
