import React, { useState } from 'react';
import { NavLink, useLocation } from 'react-router-dom';
import { FaChevronDown, FaChevronRight, FaTachometerAlt, FaChartLine, FaMoneyBillWave, FaSearchDollar, FaBullhorn, FaKey, FaHeadset, FaBoxOpen, FaCartPlus, FaSyncAlt, FaFileInvoiceDollar, FaPercentage, FaCommentAlt, FaChartPie, FaFileAlt, FaClipboardList, FaTruck, FaCreditCard, FaWarehouse, FaComments, FaUserTag, FaChartBar, FaShareSquare, FaTruckLoading, FaMoneyCheckAlt, FaAd, FaStarHalfAlt, FaQuestionCircle } from 'react-icons/fa';
import './sidebar.css';

const Sidebar = ({ user }) => {
  const location = useLocation();
  const [sidebarCollapsed, setSidebarCollapsed] = useState(false);

  // Role-based menu items
  const menuItems = {
    admin: [
      { path: '/admin/dashboard', name: 'Dashboard', icon: <FaTachometerAlt /> },
      { path: '/admin/general-sales', name: 'General Sales', icon: <FaChartLine /> },
      { path: '/admin/finance', name: 'Finance', icon: <FaMoneyBillWave /> },
      { path: '/admin/market-analysis', name: 'Market Analysis', icon: <FaSearchDollar /> },
      { path: '/admin/campaigns', name: 'Campaigns', icon: <FaBullhorn /> },
      { path: '/admin/license-management', name: 'License Management', icon: <FaKey /> },
      { path: '/admin/support', name: 'Support', icon: <FaHeadset /> }
    ],
    customer: [
      { path: '/customer/dashboard', name: 'Dashboard', icon: <FaTachometerAlt /> },
      { path: '/customer/purchased-software', name: 'My Software', icon: <FaBoxOpen /> },
      { path: '/customer/software-purchase', name: 'Purchase', icon: <FaCartPlus /> },
      { path: '/customer/license-updates', name: 'License Updates', icon: <FaSyncAlt /> },
      { path: '/customer/payment-invoice', name: 'Payments & Invoices', icon: <FaFileInvoiceDollar /> },
      { path: '/customer/promotions', name: 'Promotions', icon: <FaPercentage /> },
      { path: '/customer/support-feedback', name: 'Support & Feedback', icon: <FaCommentAlt /> }
    ],
    distributor: [
      { path: '/distributor/dashboard', name: 'Dashboard', icon: <FaTachometerAlt /> },
      { path: '/distributor/sales-performance', name: 'Sales Performance', icon: <FaChartPie /> },
      { path: '/distributor/sales-reports', name: 'Sales Reports', icon: <FaFileAlt /> },
      { path: '/distributor/order-management', name: 'Order Management', icon: <FaClipboardList /> },
      { path: '/distributor/license-distribution', name: 'License Distribution', icon: <FaTruck /> },
      { path: '/distributor/payment-billing', name: 'Payment & Billing', icon: <FaCreditCard /> },
      { path: '/distributor/stock-campaign', name: 'Stock & Campaigns', icon: <FaWarehouse /> },
      { path: '/distributor/retailer-feedback', name: 'Retailer Feedback', icon: <FaComments /> }
    ],
    retailer: [
      { path: '/retailer/dashboard', name: 'Dashboard', icon: <FaTachometerAlt /> },
      { path: '/retailer/customer-sales', name: 'Customer Sales', icon: <FaUserTag /> },
      { path: '/retailer/sales-reports', name: 'Sales Reports', icon: <FaChartBar /> },
      { path: '/retailer/license-distribution', name: 'License Distribution', icon: <FaShareSquare /> },
      { path: '/retailer/distributor-orders', name: 'Distributor Orders', icon: <FaTruckLoading /> },
      { path: '/retailer/payment-collection', name: 'Payment Collection', icon: <FaMoneyCheckAlt /> },
      { path: '/retailer/campaign-management', name: 'Campaigns', icon: <FaAd /> },
      { path: '/retailer/customer-feedback', name: 'Customer Feedback', icon: <FaStarHalfAlt /> },
      { path: '/retailer/sales-support', name: 'Support Requests', icon: <FaQuestionCircle /> }
    ]
  };

  const currentRole = user?.role?.toLowerCase() || 'customer';
  const currentMenu = menuItems[currentRole] || [];

  const toggleSidebar = () => {
    setSidebarCollapsed(!sidebarCollapsed);
  };

  return (
    <div className={`sidebar ${sidebarCollapsed ? 'collapsed' : ''}`}>
      <button className="sidebar-toggle" onClick={toggleSidebar}>
        {sidebarCollapsed ? <FaChevronRight /> : <FaChevronDown />}
      </button>
      
      <div className="sidebar-header">
        <div className="logo-container">
          <img 
            src={user?.companyLogo || 'https://via.placeholder.com/40x40?text=Logo'} 
            alt="Company Logo" 
            className="company-logo" 
          />
          {!sidebarCollapsed && <h3>{user?.role || 'User'} Panel</h3>}
        </div>
      </div>
      
      <nav className="sidebar-nav">
        <ul>
          {currentMenu.map((item, index) => (
            <li key={index}>
              <NavLink 
                to={item.path}
                className={({ isActive }) => 
                  `nav-link ${isActive ? 'active' : ''} ${sidebarCollapsed ? 'collapsed' : ''}`
                }
              >
                {({ isActive }) => (
                  <>
                    <span className="nav-icon">{item.icon}</span>
                    {!sidebarCollapsed && <span className="nav-text">{item.name}</span>}
                    {!sidebarCollapsed && isActive && <div className="active-indicator"></div>}
                  </>
                )}
              </NavLink>
            </li>
          ))}
        </ul>
      </nav>
      
      
    </div>
  );
};

export default Sidebar;